@@ -92,6 +92,7 @@ public class CqlPrepareHandler implements Throttled {
   private final Timeout scheduledTimeout;
   private final RequestThrottler throttler;
   private final Boolean prepareOnAllNodes;
+  private final DriverExecutionProfile executionProfile;
   private volatile InitialPrepareCallback initialCallback;
 
   // The errors on the nodes that were already tried (lazily initialized on the first error).
@@ -111,7 +112,7 @@ public class CqlPrepareHandler implements Throttled {
     this.initialRequest = request;
     this.session = session;
     this.context = context;
-    DriverExecutionProfile executionProfile = Conversions.resolveExecutionProfile(request, context);
+    executionProfile = Conversions.resolveExecutionProfile(request, context);
     this.queryPlan =
         context
             .getLoadBalancingPolicyWrapper()
@@ -123,6 +124,7 @@ public class CqlPrepareHandler implements Throttled {
           try {
             if (t instanceof CancellationException) {
               cancelTimeout();
+              context.getRequestThrottler().signalCancel(this);
             }
           } catch (Throwable t2) {
             Loggers.warnWithException(LOG, "[{}] Uncaught exception", logPrefix, t2);
@@ -131,7 +133,7 @@ public class CqlPrepareHandler implements Throttled {
         });
     this.timer = context.getNettyOptions().getTimer();
 
-    Duration timeout = Conversions.resolveRequestTimeout(request, context);
+    Duration timeout = Conversions.resolveRequestTimeout(request, executionProfile);
     this.scheduledTimeout = scheduleTimeout(timeout);
     this.prepareOnAllNodes = executionProfile.getBoolean(DefaultDriverOption.PREPARE_ON_ALL_NODES);
 
@@ -292,7 +294,7 @@ public class CqlPrepareHandler implements Throttled {
               false,
               toPrepareMessage(request),
               request.getCustomPayload(),
-              Conversions.resolveRequestTimeout(request, context),
+              Conversions.resolveRequestTimeout(request, executionProfile),
               throttler,
               session.getMetricUpdater(),
               logPrefix);
@@ -419,7 +421,7 @@ public class CqlPrepareHandler implements Throttled {
       } else {
         // Because prepare requests are known to always be idempotent, we call the retry policy
         // directly, without checking the flag.
-        RetryPolicy retryPolicy = Conversions.resolveRetryPolicy(request, context);
+        RetryPolicy retryPolicy = Conversions.resolveRetryPolicy(context, executionProfile);
         RetryVerdict verdict = retryPolicy.onErrorResponseVerdict(request, error, retryCount);
         processRetryVerdict(verdict, error);
       }
@@ -457,7 +459,7 @@ public class CqlPrepareHandler implements Throttled {
       LOG.trace("[{}] Request failure, processing: {}", logPrefix, error.toString());
       RetryVerdict verdict;
       try {
-        RetryPolicy retryPolicy = Conversions.resolveRetryPolicy(request, context);
+        RetryPolicy retryPolicy = Conversions.resolveRetryPolicy(context, executionProfile);
         verdict = retryPolicy.onRequestAbortedVerdict(request, error, retryCount);
       } catch (Throwable cause) {
         setFinalError(
