@@ -37,6 +37,7 @@ import com.datastax.oss.driver.api.core.session.Request;
 import com.datastax.oss.driver.api.core.session.Session;
 import com.datastax.oss.driver.api.core.specex.SpeculativeExecutionPolicy;
 import com.datastax.oss.driver.api.core.time.TimestampGenerator;
+import com.datastax.oss.driver.api.core.tracker.RequestIdGenerator;
 import com.datastax.oss.driver.api.core.type.codec.registry.CodecRegistry;
 import com.datastax.oss.driver.internal.core.DefaultConsistencyLevelRegistry;
 import com.datastax.oss.driver.internal.core.ProtocolFeature;
@@ -170,7 +171,8 @@ public class RequestHandlerTestHarness implements AutoCloseable {
 
     when(context.getRequestTracker()).thenReturn(new NoopRequestTracker(context));
 
-    when(context.getRequestIdGenerator()).thenReturn(Optional.empty());
+    when(context.getRequestIdGenerator())
+        .thenReturn(Optional.ofNullable(builder.requestIdGenerator));
   }
 
   public DefaultSession getSession() {
@@ -203,6 +205,7 @@ public class RequestHandlerTestHarness implements AutoCloseable {
     private final List<PoolBehavior> poolBehaviors = new ArrayList<>();
     private boolean defaultIdempotence;
     private ProtocolVersion protocolVersion;
+    private RequestIdGenerator requestIdGenerator;
 
     /**
      * Sets the given node as the next one in the query plan; an empty pool will be simulated when
@@ -258,6 +261,11 @@ public class RequestHandlerTestHarness implements AutoCloseable {
       return this;
     }
 
+    public Builder withRequestIdGenerator(RequestIdGenerator requestIdGenerator) {
+      this.requestIdGenerator = requestIdGenerator;
+      return this;
+    }
+
     /**
      * Sets the given node as the next one in the query plan; the test code is responsible of
      * calling the methods on the returned object to complete the write and the query.
