@@ -32,6 +32,7 @@ import com.datastax.oss.driver.api.core.cql.Row;
 import com.datastax.oss.driver.api.core.cql.SimpleStatement;
 import com.datastax.oss.driver.api.core.cql.Statement;
 import com.datastax.oss.driver.api.core.data.CqlDuration;
+import com.datastax.oss.driver.api.core.data.CqlVector;
 import com.datastax.oss.driver.api.core.data.SettableByIndex;
 import com.datastax.oss.driver.api.core.data.SettableByName;
 import com.datastax.oss.driver.api.core.data.TupleValue;
@@ -183,6 +184,7 @@ public class DataTypeIT {
     // 5) include map<type, int>
     // 6) include tuple<int, type>
     // 7) include udt<int, type>
+    // 8) include vector<type>
     return Arrays.stream(primitiveSamples)
         .flatMap(
             o -> {
@@ -263,6 +265,30 @@ public class DataTypeIT {
               UdtValue udtValue2 = udt.newValue(1, o[1]);
               samples.add(new Object[] {udt, udtValue2});
 
+              if (CCM_RULE.getCassandraVersion().compareTo(Version.parse("5.0")) >= 0) {
+                // vector of type
+                CqlVector<?> vector = CqlVector.newInstance(o[1]);
+                samples.add(new Object[] {DataTypes.vectorOf(dataType, 1), vector});
+              }
+
+              return samples.stream();
+            })
+        .toArray(Object[][]::new);
+  }
+
+  @DataProvider
+  public static Object[][] addVectors() {
+    Object[][] previousSamples = typeSamples();
+    if (CCM_RULE.getCassandraVersion().compareTo(Version.parse("5.0")) < 0) return previousSamples;
+    return Arrays.stream(previousSamples)
+        .flatMap(
+            o -> {
+              List<Object[]> samples = new ArrayList<>();
+              samples.add(o);
+              if (o[1] == null) return samples.stream();
+              DataType dataType = (DataType) o[0];
+              CqlVector<?> vector = CqlVector.newInstance(o[1]);
+              samples.add(new Object[] {DataTypes.vectorOf(dataType, 1), vector});
               return samples.stream();
             })
         .toArray(Object[][]::new);
@@ -278,7 +304,7 @@ public class DataTypeIT {
 
     List<String> columnData = new ArrayList<>();
 
-    for (Object[] sample : typeSamples()) {
+    for (Object[] sample : addVectors()) {
       DataType dataType = (DataType) sample[0];
 
       if (!typeToColumnName.containsKey(dataType)) {
@@ -308,7 +334,7 @@ public class DataTypeIT {
     return keyCounter.incrementAndGet();
   }
 
-  @UseDataProvider("typeSamples")
+  @UseDataProvider("addVectors")
   @Test
   public <K> void should_insert_non_primary_key_column_simple_statement_using_format(
       DataType dataType, K value, K expectedPrimitiveValue) {
@@ -335,7 +361,7 @@ public class DataTypeIT {
     readValue(select, dataType, value, expectedPrimitiveValue);
   }
 
-  @UseDataProvider("typeSamples")
+  @UseDataProvider("addVectors")
   @Test
   public <K> void should_insert_non_primary_key_column_simple_statement_positional_value(
       DataType dataType, K value, K expectedPrimitiveValue) {
@@ -358,7 +384,7 @@ public class DataTypeIT {
     readValue(select, dataType, value, expectedPrimitiveValue);
   }
 
-  @UseDataProvider("typeSamples")
+  @UseDataProvider("addVectors")
   @Test
   public <K> void should_insert_non_primary_key_column_simple_statement_named_value(
       DataType dataType, K value, K expectedPrimitiveValue) {
@@ -382,7 +408,7 @@ public class DataTypeIT {
     readValue(select, dataType, value, expectedPrimitiveValue);
   }
 
-  @UseDataProvider("typeSamples")
+  @UseDataProvider("addVectors")
   @Test
   public <K> void should_insert_non_primary_key_column_bound_statement_positional_value(
       DataType dataType, K value, K expectedPrimitiveValue) {
@@ -411,7 +437,7 @@ public class DataTypeIT {
     readValue(boundSelect, dataType, value, expectedPrimitiveValue);
   }
 
-  @UseDataProvider("typeSamples")
+  @UseDataProvider("addVectors")
   @Test
   public <K> void should_insert_non_primary_key_column_bound_statement_named_value(
       DataType dataType, K value, K expectedPrimitiveValue) {
