@@ -47,6 +47,7 @@ import com.datastax.oss.driver.api.mapper.annotations.Transient;
 import com.datastax.oss.driver.api.mapper.annotations.Update;
 import com.datastax.oss.driver.api.mapper.entity.saving.NullSavingStrategy;
 import com.datastax.oss.driver.api.testinfra.ccm.CcmRule;
+import com.datastax.oss.driver.api.testinfra.ccm.SchemaChangeSynchronizer;
 import com.datastax.oss.driver.api.testinfra.session.SessionRule;
 import com.datastax.oss.driver.categories.ParallelizableTests;
 import com.datastax.oss.driver.shaded.guava.common.collect.ImmutableList;
@@ -83,22 +84,27 @@ public class EntityPolymorphismIT {
   @BeforeClass
   public static void setup() {
     CqlSession session = SESSION_RULE.session();
-    for (String query :
-        ImmutableList.of(
-            "CREATE TYPE point2d (\"X\" int, \"Y\" int)",
-            "CREATE TYPE point3d (\"X\" int, \"Y\" int, \"Z\" int)",
-            "CREATE TABLE circles (circle_id uuid PRIMARY KEY, center2d frozen<point2d>, radius "
-                + "double, tags set<text>)",
-            "CREATE TABLE rectangles (rect_id uuid PRIMARY KEY, bottom_left frozen<point2d>, top_right frozen<point2d>, tags set<text>)",
-            "CREATE TABLE squares (square_id uuid PRIMARY KEY, bottom_left frozen<point2d>, top_right frozen<point2d>, tags set<text>)",
-            "CREATE TABLE spheres (sphere_id uuid PRIMARY KEY, center3d frozen<point3d>, radius "
-                + "double, tags set<text>)",
-            "CREATE TABLE devices (device_id uuid PRIMARY KEY, name text)",
-            "CREATE TABLE tracked_devices (device_id uuid PRIMARY KEY, name text, location text)",
-            "CREATE TABLE simple_devices (id uuid PRIMARY KEY, in_use boolean)")) {
-      session.execute(
-          SimpleStatement.builder(query).setExecutionProfile(SESSION_RULE.slowProfile()).build());
-    }
+    SchemaChangeSynchronizer.withLock(
+        () -> {
+          for (String query :
+              ImmutableList.of(
+                  "CREATE TYPE point2d (\"X\" int, \"Y\" int)",
+                  "CREATE TYPE point3d (\"X\" int, \"Y\" int, \"Z\" int)",
+                  "CREATE TABLE circles (circle_id uuid PRIMARY KEY, center2d frozen<point2d>, radius "
+                      + "double, tags set<text>)",
+                  "CREATE TABLE rectangles (rect_id uuid PRIMARY KEY, bottom_left frozen<point2d>, top_right frozen<point2d>, tags set<text>)",
+                  "CREATE TABLE squares (square_id uuid PRIMARY KEY, bottom_left frozen<point2d>, top_right frozen<point2d>, tags set<text>)",
+                  "CREATE TABLE spheres (sphere_id uuid PRIMARY KEY, center3d frozen<point3d>, radius "
+                      + "double, tags set<text>)",
+                  "CREATE TABLE devices (device_id uuid PRIMARY KEY, name text)",
+                  "CREATE TABLE tracked_devices (device_id uuid PRIMARY KEY, name text, location text)",
+                  "CREATE TABLE simple_devices (id uuid PRIMARY KEY, in_use boolean)")) {
+            session.execute(
+                SimpleStatement.builder(query)
+                    .setExecutionProfile(SESSION_RULE.slowProfile())
+                    .build());
+          }
+        });
     mapper = new EntityPolymorphismIT_TestMapperBuilder(session).build();
   }
 
