@@ -18,6 +18,7 @@
 package com.datastax.oss.driver.api.testinfra.ccm;
 
 import com.datastax.oss.driver.api.core.Version;
+import com.datastax.oss.driver.api.testinfra.requirement.BackendType;
 import com.datastax.oss.driver.shaded.guava.common.base.Joiner;
 import com.datastax.oss.driver.shaded.guava.common.io.Resources;
 import java.io.File;
@@ -54,6 +55,9 @@ public class CcmBridge implements AutoCloseable {
 
   private static final Logger LOG = LoggerFactory.getLogger(CcmBridge.class);
 
+  public static BackendType DISTRIBUTION =
+      BackendType.valueOf(
+          System.getProperty("ccm.distribution", BackendType.CASSANDRA.name()).toUpperCase());
   public static final Version VERSION =
       Objects.requireNonNull(Version.parse(System.getProperty("ccm.version", "4.0.0")));
 
@@ -61,8 +65,6 @@ public class CcmBridge implements AutoCloseable {
 
   public static final String BRANCH = System.getProperty("ccm.branch");
 
-  public static final Boolean DSE_ENABLEMENT = Boolean.getBoolean("ccm.dse");
-
   public static final String CLUSTER_NAME = "ccm_1";
 
   public static final String DEFAULT_CLIENT_TRUSTSTORE_PASSWORD = "fakePasswordForTests";
@@ -101,22 +103,21 @@ public class CcmBridge implements AutoCloseable {
       createTempStore(DEFAULT_SERVER_LOCALHOST_KEYSTORE_PATH);
 
   // major DSE versions
-  private static final Version V6_0_0 = Version.parse("6.0.0");
-  private static final Version V5_1_0 = Version.parse("5.1.0");
-  private static final Version V5_0_0 = Version.parse("5.0.0");
+  public static final Version V6_0_0 = Version.parse("6.0.0");
+  public static final Version V5_1_0 = Version.parse("5.1.0");
+  public static final Version V5_0_0 = Version.parse("5.0.0");
 
   // mapped C* versions from DSE versions
-  private static final Version V4_0_0 = Version.parse("4.0.0");
-  private static final Version V3_10 = Version.parse("3.10");
-  private static final Version V3_0_15 = Version.parse("3.0.15");
-  private static final Version V2_1_19 = Version.parse("2.1.19");
+  public static final Version V4_0_0 = Version.parse("4.0.0");
+  public static final Version V3_10 = Version.parse("3.10");
+  public static final Version V3_0_15 = Version.parse("3.0.15");
+  public static final Version V2_1_19 = Version.parse("2.1.19");
+
+  // mapped C* versions from HCD versions
+  public static final Version V4_0_11 = Version.parse("4.0.11");
 
   static {
-    if (DSE_ENABLEMENT) {
-      LOG.info("CCM Bridge configured with DSE version {}", VERSION);
-    } else {
-      LOG.info("CCM Bridge configured with Apache Cassandra version {}", VERSION);
-    }
+    LOG.info("CCM Bridge configured with {} version {}", DISTRIBUTION.getFriendlyName(), VERSION);
   }
 
   private final int[] nodes;
@@ -175,31 +176,31 @@ public class CcmBridge implements AutoCloseable {
     return System.getProperty("os.name", "").toLowerCase(Locale.US).contains("win");
   }
 
-  public Optional<Version> getDseVersion() {
-    return DSE_ENABLEMENT ? Optional.of(VERSION) : Optional.empty();
+  public static boolean isDistributionOf(BackendType type) {
+    return DISTRIBUTION == type;
   }
 
-  public Version getCassandraVersion() {
-    if (!DSE_ENABLEMENT) {
+  public static boolean isDistributionOf(BackendType type, VersionComparator comparator) {
+    return isDistributionOf(type)
+        && comparator.accept(getDistributionVersion(), getCassandraVersion());
+  }
+
+  public static Version getDistributionVersion() {
+    return VERSION;
+  }
+
+  public static Version getCassandraVersion() {
+    if (isDistributionOf(BackendType.CASSANDRA)) {
       return VERSION;
-    } else {
-      Version stableVersion = VERSION.nextStable();
-      if (stableVersion.compareTo(V6_0_0) >= 0) {
-        return V4_0_0;
-      } else if (stableVersion.compareTo(V5_1_0) >= 0) {
-        return V3_10;
-      } else if (stableVersion.compareTo(V5_0_0) >= 0) {
-        return V3_0_15;
-      } else {
-        return V2_1_19;
-      }
     }
+    return DistributionCassandraVersions.getCassandraVersion(DISTRIBUTION, VERSION);
   }
 
   private String getCcmVersionString(Version version) {
-    // for 4.0 pre-releases, the CCM version string needs to be "4.0-alpha1" or "4.0-alpha2"
-    // Version.toString() always adds a patch value, even if it's not specified when parsing.
-    if (version.getMajor() == 4
+    // for 4.0 or 5.0 pre-releases, the CCM version string needs to be "4.0-alpha1", "4.0-alpha2" or
+    // "5.0-beta1" Version.toString() always adds a patch value, even if it's not specified when
+    // parsing.
+    if (version.getMajor() >= 4
         && version.getMinor() == 0
         && version.getPatch() == 0
         && version.getPreReleaseLabels() != null) {
@@ -224,9 +225,7 @@ public class CcmBridge implements AutoCloseable {
       } else {
         createOptions.add("-v " + getCcmVersionString(VERSION));
       }
-      if (DSE_ENABLEMENT) {
-        createOptions.add("--dse");
-      }
+      createOptions.addAll(Arrays.asList(DISTRIBUTION.getCcmOptions()));
       execute(
           "create",
           CLUSTER_NAME,
@@ -251,7 +250,7 @@ public class CcmBridge implements AutoCloseable {
       // If we're dealing with anything more recent than 2.2 explicitly enable UDF... but run it
       // through our conversion process to make
       // sure more recent versions don't have a problem.
-      if (cassandraVersion.compareTo(Version.V2_2_0) >= 0) {
+      if (cassandraVersion.compareTo(Version.V2_2_0) >= 0 || isDistributionOf(BackendType.HCD)) {
         String originalKey = "enable_user_defined_functions";
         Object originalValue = "true";
         execute(
@@ -263,7 +262,7 @@ public class CcmBridge implements AutoCloseable {
       }
 
       // Note that we aren't performing any substitution on DSE key/value props (at least for now)
-      if (DSE_ENABLEMENT) {
+      if (isDistributionOf(BackendType.DSE)) {
         for (Map.Entry<String, Object> conf : dseConfiguration.entrySet()) {
           execute("updatedseconf", String.format("%s:%s", conf.getKey(), conf.getValue()));
         }
@@ -292,8 +291,7 @@ public class CcmBridge implements AutoCloseable {
   public void start() {
     if (started.compareAndSet(false, true)) {
       List<String> cmdAndArgs = Lists.newArrayList("start", jvmArgs, "--wait-for-binary-proto");
-      overrideJvmVersionForDseWorkloads()
-          .ifPresent(jvmVersion -> cmdAndArgs.add(String.format("--jvm_version=%d", jvmVersion)));
+      updateJvmVersion(cmdAndArgs);
       try {
         execute(cmdAndArgs.toArray(new String[0]));
       } catch (RuntimeException re) {
@@ -324,9 +322,13 @@ public class CcmBridge implements AutoCloseable {
 
   public void start(int n) {
     List<String> cmdAndArgs = Lists.newArrayList("node" + n, "start");
+    updateJvmVersion(cmdAndArgs);
+    execute(cmdAndArgs.toArray(new String[0]));
+  }
+
+  private void updateJvmVersion(List<String> cmdAndArgs) {
     overrideJvmVersionForDseWorkloads()
         .ifPresent(jvmVersion -> cmdAndArgs.add(String.format("--jvm_version=%d", jvmVersion)));
-    execute(cmdAndArgs.toArray(new String[0]));
   }
 
   public void stop(int n) {
@@ -334,11 +336,10 @@ public class CcmBridge implements AutoCloseable {
   }
 
   public void add(int n, String dc) {
-    if (getDseVersion().isPresent()) {
-      execute("add", "-i", ipPrefix + n, "-d", dc, "node" + n, "--dse");
-    } else {
-      execute("add", "-i", ipPrefix + n, "-d", dc, "node" + n);
-    }
+    List<String> addOptions = new ArrayList<>();
+    addOptions.addAll(Arrays.asList("add", "-i", ipPrefix + n, "-d", dc, "node" + n));
+    addOptions.addAll(Arrays.asList(DISTRIBUTION.getCcmOptions()));
+    execute(addOptions.toArray(new String[0]));
     start(n);
   }
 
@@ -423,7 +424,9 @@ public class CcmBridge implements AutoCloseable {
 
   @Override
   public void close() {
-    remove();
+    if (created.compareAndSet(true, false)) {
+      remove();
+    }
   }
 
   /**
@@ -469,11 +472,12 @@ public class CcmBridge implements AutoCloseable {
       return Optional.empty();
     }
 
-    if (!DSE_ENABLEMENT || !getDseVersion().isPresent()) {
+    if (!isDistributionOf(BackendType.DSE)) {
       return Optional.empty();
     }
 
-    if (getDseVersion().get().compareTo(Version.parse("6.8.19")) < 0) {
+    if (getDistributionVersion().compareTo(Version.V6_9_0) >= 0) {
+      // DSE 6.9.0 supports only JVM 11 onwards (also with graph workload)
       return Optional.empty();
     }
 
@@ -634,4 +638,8 @@ public class CcmBridge implements AutoCloseable {
           dseWorkloads);
     }
   }
+
+  public interface VersionComparator {
+    boolean accept(Version distribution, Version cassandra);
+  }
 }
